==> codepipeline-api-0.10.0-sources.jar: software/amazon/awscdk/services/codepipeline/api/DeployActionProps.java <==
package software.amazon.awscdk.services.codepipeline.api;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:46:12.152Z")
public interface DeployActionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.codepipeline.api.CommonActionProps {
    software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds();
    void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value);
    java.lang.String getProvider();
    void setProvider(final java.lang.String value);
    java.lang.Object getConfiguration();
    void setConfiguration(final java.lang.Object value);
    software.amazon.awscdk.services.codepipeline.api.Artifact getInputArtifact();
    void setInputArtifact(final software.amazon.awscdk.services.codepipeline.api.Artifact value);

    /**
     * @return a {@link Builder} of {@link DeployActionProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link DeployActionProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds _artifactBounds;
        private java.lang.String _provider;
        @javax.annotation.Nullable
        private java.lang.Object _configuration;
        @javax.annotation.Nullable
        private software.amazon.awscdk.services.codepipeline.api.Artifact _inputArtifact;
        private software.amazon.awscdk.services.codepipeline.api.IStage _stage;

        /**
         * Sets the value of ArtifactBounds
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this._artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
            return this;
        }
        /**
         * Sets the value of Provider
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withProvider(final java.lang.String value) {
            this._provider = java.util.Objects.requireNonNull(value, "provider is required");
            return this;
        }
        /**
         * Sets the value of Configuration
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this._configuration = value;
            return this;
        }
        /**
         * Sets the value of InputArtifact
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withInputArtifact(@javax.annotation.Nullable final software.amazon.awscdk.services.codepipeline.api.Artifact value) {
            this._inputArtifact = value;
            return this;
        }
        /**
         * Sets the value of Stage
         * @param value The Pipeline Stage to add this Action to.
         * @return {@code this}
         */
        public Builder withStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this._stage = java.util.Objects.requireNonNull(value, "stage is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link DeployActionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public DeployActionProps build() {
            return new DeployActionProps() {
                private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds $artifactBounds = java.util.Objects.requireNonNull(_artifactBounds, "artifactBounds is required");
                private java.lang.String $provider = java.util.Objects.requireNonNull(_provider, "provider is required");
                @javax.annotation.Nullable
                private java.lang.Object $configuration = _configuration;
                @javax.annotation.Nullable
                private software.amazon.awscdk.services.codepipeline.api.Artifact $inputArtifact = _inputArtifact;
                private software.amazon.awscdk.services.codepipeline.api.IStage $stage = java.util.Objects.requireNonNull(_stage, "stage is required");

                @Override
                public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
                    return this.$artifactBounds;
                }

                @Override
                public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
                    this.$artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
                }

                @Override
                public java.lang.String getProvider() {
                    return this.$provider;
                }

                @Override
                public void setProvider(final java.lang.String value) {
                    this.$provider = java.util.Objects.requireNonNull(value, "provider is required");
                }

                @Override
                public java.lang.Object getConfiguration() {
                    return this.$configuration;
                }

                @Override
                public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
                    this.$configuration = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.Artifact getInputArtifact() {
                    return this.$inputArtifact;
                }

                @Override
                public void setInputArtifact(@javax.annotation.Nullable final software.amazon.awscdk.services.codepipeline.api.Artifact value) {
                    this.$inputArtifact = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
                    return this.$stage;
                }

                @Override
                public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
                    this.$stage = java.util.Objects.requireNonNull(value, "stage is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codepipeline.api.DeployActionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
            return this.jsiiGet("artifactBounds", software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds.class);
        }

        @Override
        public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this.jsiiSet("artifactBounds", java.util.Objects.requireNonNull(value, "artifactBounds is required"));
        }

        @Override
        public java.lang.String getProvider() {
            return this.jsiiGet("provider", java.lang.String.class);
        }

        @Override
        public void setProvider(final java.lang.String value) {
            this.jsiiSet("provider", java.util.Objects.requireNonNull(value, "provider is required"));
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.Object getConfiguration() {
            return this.jsiiGet("configuration", java.lang.Object.class);
        }

        @Override
        public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this.jsiiSet("configuration", value);
        }

        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.codepipeline.api.Artifact getInputArtifact() {
            return this.jsiiGet("inputArtifact", software.amazon.awscdk.services.codepipeline.api.Artifact.class);
        }

        @Override
        public void setInputArtifact(@javax.annotation.Nullable final software.amazon.awscdk.services.codepipeline.api.Artifact value) {
            this.jsiiSet("inputArtifact", value);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
            return this.jsiiGet("stage", software.amazon.awscdk.services.codepipeline.api.IStage.class);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this.jsiiSet("stage", java.util.Objects.requireNonNull(value, "stage is required"));
        }
    }
}

==> codepipeline-api-0.11.0-sources.jar: software/amazon/awscdk/services/codepipeline/api/DeployActionProps.java <==
package software.amazon.awscdk.services.codepipeline.api;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.7 (build b1c202b)", date = "2018-10-11T18:02:06.199Z")
public interface DeployActionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.codepipeline.api.CommonActionProps, software.amazon.awscdk.services.codepipeline.api.CommonActionConstructProps {
    software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds();
    void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value);
    java.lang.String getProvider();
    void setProvider(final java.lang.String value);
    java.lang.Object getConfiguration();
    void setConfiguration(final java.lang.Object value);
    software.amazon.awscdk.services.codepipeline.api.Artifact getInputArtifact();
    void setInputArtifact(final software.amazon.awscdk.services.codepipeline.api.Artifact value);

    /**
     * @return a {@link Builder} of {@link DeployActionProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link DeployActionProps}
     */
    final class Builder {
        private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds _artifactBounds;
        private java.lang.String _provider;
        @javax.annotation.Nullable
        private java.lang.Object _configuration;
        @javax.annotation.Nullable
        private software.amazon.awscdk.services.codepipeline.api.Artifact _inputArtifact;
        @javax.annotation.Nullable
        private java.lang.Number _runOrder;
        private software.amazon.awscdk.services.codepipeline.api.IStage _stage;

        /**
         * Sets the value of ArtifactBounds
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this._artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
            return this;
        }
        /**
         * Sets the value of Provider
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withProvider(final java.lang.String value) {
            this._provider = java.util.Objects.requireNonNull(value, "provider is required");
            return this;
        }
        /**
         * Sets the value of Configuration
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this._configuration = value;
            return this;
        }
        /**
         * Sets the value of InputArtifact
         * @param value the value to be set
         * @return {@code this}
         */
        public Builder withInputArtifact(@javax.annotation.Nullable final software.amazon.awscdk.services.codepipeline.api.Artifact value) {
            this._inputArtifact = value;
            return this;
        }
        /**
         * Sets the value of RunOrder
         * @param value The runOrder property for this Action.
RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @return {@code this}
         */
        public Builder withRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this._runOrder = value;
            return this;
        }
        /**
         * Sets the value of Stage
         * @param value The Pipeline Stage to add this Action to.
         * @return {@code this}
         */
        public Builder withStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this._stage = java.util.Objects.requireNonNull(value, "stage is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link DeployActionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public DeployActionProps build() {
            return new DeployActionProps() {
                private software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds $artifactBounds = java.util.Objects.requireNonNull(_artifactBounds, "artifactBounds is required");
                private java.lang.String $provider = java.util.Objects.requireNonNull(_provider, "provider is required");
                @javax.annotation.Nullable
                private java.lang.Object $configuration = _configuration;
                @javax.annotation.Nullable
                private software.amazon.awscdk.services.codepipeline.api.Artifact $inputArtifact = _inputArtifact;
                @javax.annotation.Nullable
                private java.lang.Number $runOrder = _runOrder;
                private software.amazon.awscdk.services.codepipeline.api.IStage $stage = java.util.Objects.requireNonNull(_stage, "stage is required");

                @Override
                public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
                    return this.$artifactBounds;
                }

                @Override
                public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
                    this.$artifactBounds = java.util.Objects.requireNonNull(value, "artifactBounds is required");
                }

                @Override
                public java.lang.String getProvider() {
                    return this.$provider;
                }

                @Override
                public void setProvider(final java.lang.String value) {
                    this.$provider = java.util.Objects.requireNonNull(value, "provider is required");
                }

                @Override
                public java.lang.Object getConfiguration() {
                    return this.$configuration;
                }

                @Override
                public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
                    this.$configuration = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.Artifact getInputArtifact() {
                    return this.$inputArtifact;
                }

                @Override
                public void setInputArtifact(@javax.annotation.Nullable final software.amazon.awscdk.services.codepipeline.api.Artifact value) {
                    this.$inputArtifact = value;
                }

                @Override
                public java.lang.Number getRunOrder() {
                    return this.$runOrder;
                }

                @Override
                public void setRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
                    this.$runOrder = value;
                }

                @Override
                public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
                    return this.$stage;
                }

                @Override
                public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
                    this.$stage = java.util.Objects.requireNonNull(value, "stage is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.codepipeline.api.DeployActionProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        @Override
        public software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds getArtifactBounds() {
            return this.jsiiGet("artifactBounds", software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds.class);
        }

        @Override
        public void setArtifactBounds(final software.amazon.awscdk.services.codepipeline.api.ActionArtifactBounds value) {
            this.jsiiSet("artifactBounds", java.util.Objects.requireNonNull(value, "artifactBounds is required"));
        }

        @Override
        public java.lang.String getProvider() {
            return this.jsiiGet("provider", java.lang.String.class);
        }

        @Override
        public void setProvider(final java.lang.String value) {
            this.jsiiSet("provider", java.util.Objects.requireNonNull(value, "provider is required"));
        }

        @Override
        @javax.annotation.Nullable
        public java.lang.Object getConfiguration() {
            return this.jsiiGet("configuration", java.lang.Object.class);
        }

        @Override
        public void setConfiguration(@javax.annotation.Nullable final java.lang.Object value) {
            this.jsiiSet("configuration", value);
        }

        @Override
        @javax.annotation.Nullable
        public software.amazon.awscdk.services.codepipeline.api.Artifact getInputArtifact() {
            return this.jsiiGet("inputArtifact", software.amazon.awscdk.services.codepipeline.api.Artifact.class);
        }

        @Override
        public void setInputArtifact(@javax.annotation.Nullable final software.amazon.awscdk.services.codepipeline.api.Artifact value) {
            this.jsiiSet("inputArtifact", value);
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Number getRunOrder() {
            return this.jsiiGet("runOrder", java.lang.Number.class);
        }

        /**
         * The runOrder property for this Action.
         * RunOrder determines the relative order in which multiple Actions in the same Stage execute.
         * @default 1
         * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/reference-pipeline-structure.html
         */
        @Override
        public void setRunOrder(@javax.annotation.Nullable final java.lang.Number value) {
            this.jsiiSet("runOrder", value);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public software.amazon.awscdk.services.codepipeline.api.IStage getStage() {
            return this.jsiiGet("stage", software.amazon.awscdk.services.codepipeline.api.IStage.class);
        }

        /**
         * The Pipeline Stage to add this Action to.
         */
        @Override
        public void setStage(final software.amazon.awscdk.services.codepipeline.api.IStage value) {
            this.jsiiSet("stage", java.util.Objects.requireNonNull(value, "stage is required"));
        }
    }
}
